@@ -1,6 +1,7 @@
+import click
+
 from pyp2spec.pyp2conf import create_config
 from pyp2spec.conf2spec import create_spec_file
-import click
 
 
 @click.command()
@@ -42,7 +43,7 @@ import click
     help="Provide license name",
 )
 @click.option(
-    "--spec-output", "-s",
+    "--spec-output", "-o",
     help="Provide custom output where spec file will be saved",
 )
 @click.option(
@@ -53,6 +54,10 @@ import click
     "--top-level", "-t", is_flag=True,
     help="Test only top-level modules in %check",
 )
+@click.option(
+    "--archful", "-a", is_flag=True,
+    help="Set if the resulting RPM should be arched",
+)
 def main(**options):
     click.secho("Generating configuration file", fg="cyan")
     config_file = create_config(options)
